@@ -175,7 +175,7 @@ void MiscControlPage::OnFirmware(wxCommandEvent& event)
 
 void MiscControlPage::OnSpeedChange(wxScrollEvent& event)
 {
-	auto speedText = wxString::Format(wxT("%ld"), event.GetInt());
+	auto speedText = wxString::Format(wxT("%d"), event.GetInt());
 	m_speedIndicator->SetValue(speedText);
 	m_controller.WriteCommand(wxT("set speed ") + speedText);
 	m_controller.WriteCommand(wxT("set throttle on"));
@@ -206,14 +206,14 @@ void MiscControlPage::OnSetMaxSpeed(wxCommandEvent& event)
 
 void MiscControlPage::OnMaxFrameSkipChange(wxScrollEvent& event)
 {
-	auto skipText = wxString::Format(wxT("%ld"), event.GetInt());
+	auto skipText = wxString::Format(wxT("%d"), event.GetInt());
 	m_maxFrameSkipIndicator->SetValue(skipText);
 	m_controller.WriteCommand(wxT("set maxframeskip ") + skipText);
 }
 
 void MiscControlPage::OnMinFrameSkipChange(wxScrollEvent& event)
 {
-	auto skipText = wxString::Format(wxT("%ld"), event.GetInt());
+	auto skipText = wxString::Format(wxT("%d"), event.GetInt());
 	m_minFrameSkipIndicator->SetValue(skipText);
 	m_controller.WriteCommand(wxT("set minframeskip ") + skipText);
 }
@@ -396,16 +396,16 @@ void MiscControlPage::InitConnectorPanel()
 	for (auto& connector : m_controller.GetConnectors()) {
 		wxString currentClass = m_controller.GetConnectorClass(connector);
 		if (connector == wxT("joyporta")) {
-			InitJoystickPort(connector, wxT("Joyport1Selector"), currentClass);
+			InitJoystickOrPrinterPort(connector, wxT("Joyport1Selector"), currentClass);
 		} else if (connector == wxT("joyportb")) {
-			InitJoystickPort(connector, wxT("Joyport2Selector"), currentClass);
+			InitJoystickOrPrinterPort(connector, wxT("Joyport2Selector"), currentClass);
 		} else if (connector == wxT("printerport")) {
-			InitJoystickPort(connector, wxT("PrinterportSelector"), currentClass);
+			InitJoystickOrPrinterPort(connector, wxT("PrinterportSelector"), currentClass);
 		}
 	}
 }
 
-void MiscControlPage::InitJoystickPort(wxString connector, wxString control, wxString connectorClass)
+void MiscControlPage::InitJoystickOrPrinterPort(wxString connector, wxString control, wxString connectorClass)
 {
 	const wxArrayString& classes = m_controller.GetPluggableClasses();
 	if (classes.IsEmpty()) return;
@@ -426,11 +426,9 @@ void MiscControlPage::InitJoystickPort(wxString connector, wxString control, wxS
 	}
 	box->SetValue(currentval);
 	wxString cmd = wxT("plug");
-	if (currentval == wxT("--empty--")) {
-		cmd = wxT("unplug");
-		currentval.Clear();
+	if (currentval != wxT("--empty--")) {
+		m_controller.WriteCommand(cmd + wxT(" ") + connector + wxT(" ") + currentval);
 	}
-	m_controller.WriteCommand(cmd + wxT(" ") + connector + wxT(" ") + currentval);
 }
 
 void MiscControlPage::OnChangeJoystick(wxCommandEvent& event)
@@ -530,7 +528,7 @@ void MiscControlPage::OnJoystickChanged()
 void MiscControlPage::OnChangeRenShaTurbo(wxScrollEvent& event)
 {
 	m_controller.WriteCommand(wxString::Format(
-		wxT("set renshaturbo %ld"), event.GetInt()));
+		wxT("set renshaturbo %d"), event.GetInt()));
 }
 
 void MiscControlPage::OnChangePrinterPort(wxCommandEvent& event)
@@ -565,7 +563,7 @@ void MiscControlPage::OnChangePrinterLogFile(wxCommandEvent& event)
 	wxString current = ((wxTextCtrl*)event.GetEventObject())->GetValue();
 	ConfigurationData::instance().SetParameter(ConfigurationData::CD_PRINTERFILE, current);
 	ConfigurationData::instance().SaveData();
-	m_controller.WriteCommand(wxT("set printerlogfilename ") + utils::ConvertPath(current));
+	m_controller.WriteCommand(wxT("set printerlogfilename ") + utils::ConvertPathForCommand(current));
 }
 
 void MiscControlPage::OnBrowsePrinterLogFile(wxCommandEvent& event)
