@@ -188,7 +188,7 @@ SessionPage::SessionPage(wxWindow* parent, openMSXController& controller)
 		ConfigurationData::CD_NONE, ConfigurationData::CD_NONE,
 		m_hardDiskButton, HARDDISK, 0, 0));
 	for (auto& m : media) {
-		m->control.SetDropTarget(new SessionDropTarget(&m->control));
+		m->control.SetDropTarget(new SessionDropTarget(m.get(), this));
 	}
 
 	int autorecord;
@@ -286,7 +286,7 @@ void SessionPage::OnModeRecord(wxCommandEvent& event)
 		                     defaultpath, wxT(""), path,
 		                     wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
 		if (filedlg.ShowModal() != wxID_OK) return;
-		cmd += wxT(" ") + utils::ConvertPath(filedlg.GetPath());
+		cmd += wxT(" ") + utils::ConvertPathForCommand(filedlg.GetPath());
 	}
 	m_controller.WriteCommand(cmd);
 }
@@ -551,14 +551,14 @@ void SessionPage::insertMedia(MediaInfo& m)
 	m.lastContents = contents;
 	wxString cmd = m.deviceName + wxT(" ");
 	if (!contents.IsEmpty()) {
-		cmd += utils::ConvertPath(contents);
+		cmd += utils::ConvertPathForCommand(contents);
 		if (m.mediaType == CARTRIDGE) {
 			if (!m.type.IsEmpty()) {
 				cmd += wxT(" -romtype ") + m.type;
 			}
 		}
 		for (auto& ips : m.ips) {
-			cmd += wxT(" -ips ") + utils::ConvertPath(ips);
+			cmd += wxT(" -ips ") + utils::ConvertPathForCommand(ips);
 		}
 		AddHistory(m);
 	} else {
@@ -889,6 +889,7 @@ void SessionPage::GetRomTypes()
 	wxArrayString output;
 	int code = wxExecute(cmd + wxT(" -bash -romtype"), output);
 	assert(code != -1);
+	if (code) {}; // avoid warning in build with asserts disabled
 
 	output.Sort(CompareCaseInsensitive);
 	output.Insert(wxT(""), 0);
@@ -963,15 +964,17 @@ const wxArrayString& SessionPage::GetDetectedExtensions() const
 	return m_extensionArray;
 }
 
-SessionDropTarget::SessionDropTarget(wxComboBox* target)
+SessionDropTarget::SessionDropTarget(SessionPage::MediaInfo* target, SessionPage* sessionPage)
+	: m_target(target)
+	, m_sessionPage(sessionPage)
 {
-	m_target = target;
 }
 
 bool SessionDropTarget::OnDropFiles(wxCoord x, wxCoord y, const wxArrayString& filenames)
 {
 	if (!filenames.IsEmpty()) {
-		m_target->Append(filenames[0]); // just the first for starters
+		m_target->control.SetValue(filenames[0]); // just the first for starters
+		m_sessionPage->insertMediaClear(*m_target);
 	}
 	return true;
 }
